django_geopostcodes.models — django-geopostcodes 0.1.0 documentation

# django_geopostcodes.models

Django models for django-geopostcodes.

class `django_geopostcodes.models.` `Locality`(*args, **kwargs)

  Bases: `django.db.models.base.Model`

  Defines an Locality as defined in GeoPostCodes GeoPC_xx_Places.csv files.

  exception `DoesNotExist`

    Bases: `django.core.exceptions.ObjectDoesNotExist`

  exception `Locality.` `MultipleObjectsReturned`

    Bases: `django.core.exceptions.MultipleObjectsReturned`

  `Locality.` `get_iso_display`(*moreargs, **morekwargs)
  `Locality.` `iso` = <django_countries.fields.CountryField>
  `Locality.` `objects` = <django_geopostcodes.managers.LocalityManager object>
  `Locality.` `point`